@@ -1,43 +1,9 @@
-# ***** BEGIN LICENSE BLOCK *****
-# Version: MPL 1.1/GPL 2.0/LGPL 2.1
-#
-# The contents of this file are subject to the Mozilla Public License Version
-# 1.1 (the "License"); you may not use this file except in compliance with
-# the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-#
-# Software distributed under the License is distributed on an "AS IS" basis,
-# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-# for the specific language governing rights and limitations under the
-# License.
-#
-# The Original Code is PyVEP
-#
-# The Initial Developer of the Original Code is the Mozilla Foundation.
-# Portions created by the Initial Developer are Copyright (C) 2011
-# the Initial Developer. All Rights Reserved.
-#
-# Contributor(s):
-#   Ryan Kelly (rkelly@mozilla.com)
-#
-# Alternatively, the contents of this file may be used under the terms of
-# either the GNU General Public License Version 2 or later (the "GPL"), or
-# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
-# in which case the provisions of the GPL or the LGPL are applicable instead
-# of those above. If you wish to allow use of your version of this file only
-# under the terms of either the GPL or the LGPL, and not to allow others to
-# use your version of this file under the terms of the MPL, indicate your
-# decision by deleting the provisions above and replace them with the notice
-# and other provisions required by the GPL or the LGPL. If you do not delete
-# the provisions above, a recipient may use your version of this file under
-# the terms of any one of the MPL, the GPL or the LGPL.
-#
-# ***** END LICENSE BLOCK *****
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import unittest
 
-from M2Crypto import RSA, DSA
-
 from vep.verifiers.dummy import DummyVerifier
 from vep.utils import encode_json_bytes, encode_bytes
 from vep import jwt
@@ -121,8 +87,8 @@ class TestJWT(unittest.TestCase):
         self.assertRaises(Exception, pubkey.sign, "hello")
         # And it should gracefully handle a variety of stupid input:
         #   - signature too long
-        self.assertFalse(pubkey.verify("HELLO", "X"*100))
+        self.assertFalse(pubkey.verify("HELLO", "X" * 100))
         #   - "r" value too large
-        self.assertFalse(pubkey.verify("HELLO", ("\xFF"*20) + "\x01"*20))
+        self.assertFalse(pubkey.verify("HELLO", ("\xFF" * 20) + "\x01" * 20))
         #   - "s" value too large
-        self.assertFalse(pubkey.verify("HELLO", "\x01" + ("\xFF"*20)))
+        self.assertFalse(pubkey.verify("HELLO", "\x01" + ("\xFF" * 20)))
