@@ -1,38 +1,6 @@
-# ***** BEGIN LICENSE BLOCK *****
-# Version: MPL 1.1/GPL 2.0/LGPL 2.1
-#
-# The contents of this file are subject to the Mozilla Public License Version
-# 1.1 (the "License"); you may not use this file except in compliance with
-# the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-#
-# Software distributed under the License is distributed on an "AS IS" basis,
-# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-# for the specific language governing rights and limitations under the
-# License.
-#
-# The Original Code is PyVEP
-#
-# The Initial Developer of the Original Code is the Mozilla Foundation.
-# Portions created by the Initial Developer are Copyright (C) 2011
-# the Initial Developer. All Rights Reserved.
-#
-# Contributor(s):
-#   Ryan Kelly (rkelly@mozilla.com)
-#
-# Alternatively, the contents of this file may be used under the terms of
-# either the GNU General Public License Version 2 or later (the "GPL"), or
-# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
-# in which case the provisions of the GPL or the LGPL are applicable instead
-# of those above. If you wish to allow use of your version of this file only
-# under the terms of either the GPL or the LGPL, and not to allow others to
-# use your version of this file under the terms of the MPL, indicate your
-# decision by deleting the provisions above and replace them with the notice
-# and other provisions required by the GPL or the LGPL. If you do not delete
-# the provisions above, a recipient may use your version of this file under
-# the terms of any one of the MPL, the GPL or the LGPL.
-#
-# ***** END LICENSE BLOCK *****
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import time
 import json
@@ -43,6 +11,7 @@ import vep
 from vep import jwt
 from vep import RemoteVerifier, LocalVerifier, DummyVerifier
 from vep.verifiers.local import FIFOCache
+from vep.verifiers.workerpool import WorkerPoolVerifier
 from vep.utils import encode_json_bytes, decode_json_bytes
 from vep.errors import (TrustError,
                         ConnectionError,
@@ -174,6 +143,7 @@ class TestLocalVerifier(unittest.TestCase, VerifierTestCases):
 
     def test_malformed_pub_key_document(self):
         called = []
+
         def urlopen(url, data):
             # First call must raise 404 so it will look for /pk.
             # Second call must return invalid JSON.
@@ -377,8 +347,10 @@ class TestDummyVerifier(unittest.TestCase, VerifierTestCases):
         assertion = self.verifier.make_assertion("test@example.com", "")
         self.assertTrue(verifier.verify(assertion))
         # Make it error out if re-fetching the keys
+
         def fetch_public_key(hostname):
             raise RuntimeError("key fetch disabled")
+
         verifier.fetch_public_key = fetch_public_key
         # It should be in the cache, so this works fine.
         verifier.verify(assertion)
@@ -400,8 +372,10 @@ class TestDummyVerifier(unittest.TestCase, VerifierTestCases):
         self.assertTrue(verifier.verify(assertion3))
         self.assertEquals(len(cache), 2)
         # Make it error out if re-fetching any keys
+
         def fetch_public_key(hostname):
             raise RuntimeError("key fetch disabled")
+
         verifier.fetch_public_key = fetch_public_key
         # It should have to re-fetch for 1, but not 2.
         self.assertTrue(verifier.verify(assertion2))
@@ -421,13 +395,25 @@ class TestDummyVerifier(unittest.TestCase, VerifierTestCases):
         self.assertTrue(verifier.verify(assertion2))
         self.assertEquals(len(cache), 1)
         # Check that only the second entry is in cache.
+
         def fetch_public_key(hostname):
             raise RuntimeError("key fetch disabled")
+
         verifier.fetch_public_key = fetch_public_key
         self.assertTrue(verifier.verify(assertion2))
         self.assertRaises(RuntimeError, verifier.verify, assertion1)
 
 
+class TestWorkerPoolVerifier(TestDummyVerifier):
+
+    def setUp(self):
+        self.verifier = WorkerPoolVerifier(verifier=DummyVerifier())
+        self.verifier.make_assertion = self.verifier.verifier.make_assertion
+
+    def tearDown(self):
+        self.verifier.close()
+
+
 class TestShortcutFunctions(unittest.TestCase):
 
     def test_shortcut(self):
